@@ -1,10 +1,11 @@
 """Ascend resource definition classes."""
 
 import abc
+from collections import namedtuple
+from typing import Dict, List, Optional
+
 import google.protobuf.timestamp_pb2 as timestamp_pb2
 import google.protobuf.wrappers_pb2 as wrappers_pb2
-from typing import List, Dict, Optional
-from collections import namedtuple
 
 import ascend.protos.api.api_pb2 as api_pb2
 import ascend.protos.ascend.ascend_pb2 as ascend_pb2
@@ -578,6 +579,7 @@ class DataService(Definition):
   def __init__(self,
                id: str,
                name: str,
+               data_service_type: str = None,
                description: str = None,
                credentials: Optional[List[Credential]] = None,
                connections: Optional[List[Connection]] = None,
@@ -594,10 +596,11 @@ class DataService(Definition):
     """
     self.id = id
     self.name = name
+    self.data_service_type = data_service_type
     self.description = description
     self.credentials = credentials
     self.connections = connections
     self.dataflows = dataflows
 
   def to_proto(self):
-    return api_pb2.DataService(id=self.id, name=self.name, description=self.description)
+    return api_pb2.DataService(id=self.id, name=self.name, data_service_type=self.data_service_type, description=self.description)
